body{-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Oxygen,Ubuntu,Cantarell,Fira Sans,Droid Sans,Helvetica Neue,sans-serif;margin:0}code{font-family:source-code-pro,Menlo,Monaco,Consolas,Courier New,monospace}.ca-container{grid-column-gap:0;display:grid;grid-template-columns:auto auto}.card-container{align-items:center;background-color:#fff;display:flex;flex-direction:column;font-size:14px;gap:10px;justify-content:flex-start;padding:10px}.card-container.left{border-bottom:1px solid #eaeaea;border-right:1px solid #eaeaea}.card-container.right{border-bottom:1px solid #eaeaea;border-left:1px solid #eaeaea}
/*# sourceMappingURL=main.80fdb1d5.css.map*/